%global		major			38
%global         momorel 1

Summary:	JavaScript interpreter and libraries
Name:		mozjs%{major}
Version:	%{major}.8.0
Release:	%{momorel}m%{?dist}
License:	"MPLv2.0"
Group:		Development/Languages
URL:		https://developer.mozilla.org/en-US/docs/Mozilla/Projects/SpiderMonkey/Releases/38
Source0:	https://ftp.mozilla.org/pub/firefox/releases/%{version}esr/source/firefox-%{version}esr.source.tar.bz2
NoSource:       0
Source1:	LICENSE.txt

# According to mozilla devs x86_64 is the only 64-bit architecture. I tend to not agree with them.
Patch0:	fix-64bit-archs.patch
# same issue on s390 as in XUL/FF - https://bugzilla.redhat.com/show_bug.cgi?id=1219542
Patch1:	rhbz-1219542-s390-build.patch
# Allow mozjs to work on machines with >47 bits of VA
Patch2: mozbz-1143022.patch

BuildRequires:	pkgconfig(icu-i18n)
BuildRequires:	pkgconfig(nspr)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	readline-devel
BuildRequires:	zip
BuildRequires:	python-devel
BuildRequires:	perl-devel

%description
JavaScript is the Netscape-developed object scripting language used in millions
of web pages and server applications worldwide. Netscape's JavaScript is a
super set of the ECMA-262 Edition 3 (ECMAScript) standard scripting language,
with only mild differences from the published standard.

%package devel
Summary: Header files, libraries and development documentation for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains the header files, static libraries and development
documentation for %{name}. If you like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%setup -q -n mozilla-esr%{major}/js/src
%patch0 -p1
%ifarch s390
%patch1 -p3 -b .rhbz-1219542-s390
%endif
%patch2 -p3

#%if 0%{?fedora} > 22
# Correct failed to link tests due to hardened build
sed -i 's|"-O2"|"-O2 -fPIC"|' configure
#%endif
# Correct sed expression for new sed
sed -i 's|\^\[:space:\]|^\[\[:space:\]\]|g' configure

# Remove zlib directory (to be sure using system version)
#rm -rf ../../modules/zlib

# Fix release number
#head -n -1 ../../config/milestone.txt > ../../config/milestone.txt
#echo "%{version}" >> ../../config/milestone.txt
#
## Make mozjs these functions visible:
## JS::UTF8CharsToNewTwoByteCharsZ and JS::LossyUTF8CharsToNewTwoByteCharsZ
#sed -i 's|^\(TwoByteCharsZ\)$|JS_PUBLIC_API\(\1\)|g' vm/CharacterEncoding.cpp
#sed -i 's|^extern\ \(TwoByteCharsZ\)$|JS_PUBLIC_API\(\1\)|g' ../public/CharacterEncoding.h
## Also make visible js::DisableExtraThreads()
#sed -i '/^void$/{$!{N;s/^\(void\)\n\(js\:\:DisableExtraThreads()\)$/JS_PUBLIC_API\(\1\)\n\2/;ty;P;D;:y}}'  vm/Runtime.cpp
#sed -i 's|\(void\) \(DisableExtraThreads()\)|JS_PUBLIC_API\(\1\) \2|g'  vm/Runtime.h

%build
# Need -fpermissive due to some macros using nullptr as bool false
export CFLAGS="%{optflags} -fpermissive -fno-tree-vrp -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
export PYTHON=/usr/bin/python2
CONFIGURE_OPT=" --program-prefix= --prefix=/usr --exec-prefix=/usr --bindir=%{_bindir} --sbindir=%{_bindir} --sysconfdir=%{_sysconfdir} --datadir=%{_datadir} --includedir=/usr/include --libdir=%{_libdir} --libexecdir=/usr/libexec --localstatedir=/var --sharedstatedir=/usr/com --mandir=/usr/share/man --infodir=/usr/share/info "
#%%configure \
./configure $CONFIGURE_OPT \
	--with-system-nspr \
	--enable-threadsafe \
	--enable-readline \
	--enable-xterm-updates \
	--enable-shared-js \
	--enable-gcgenerational \
	--disable-optimize \
	--with-system-zlib \
	--enable-system-ffi \
	--with-system-icu \
	--with-intl-api \
	--enable-pie

#./configure --build=x86_64-unknown-linux-gnu --host=x86_64-unknown-linux-gnu --target=x86_64-momonga-linux --program-prefix= --prefix=/usr --exec-prefix=/usr --bindir=/usr/bin --sbindir=/usr/sbin --sysconfdir=/etc --datadir=/usr/share --includedir=/usr/include --libdir=/usr/lib64 --libexecdir=/usr/libexec --localstatedir=/var --sharedstatedir=/usr/com --mandir=/usr/share/man --infodir=/usr/share/info --with-system-nspr --enable-threadsafe --enable-readline --enable-xterm-updates --enable-shared-js --enable-gcgenerational --disable-optimize --with-system-zlib --enable-system-ffi --with-system-icu --with-intl-api --enable-pie

# Without adding these sources resulted library has weak symbols
#echo "CPPSRCS += \$(DEPTH)/mfbt/Unified_cpp_mfbt0.cpp \$(DEPTH)/../../mfbt/Compression.cpp \$(DEPTH)/../../mfbt/decimal/Decimal.cpp" >> js/src/backend.mk
#echo "STATIC_LIBS += \$(DEPTH)/mfbt/libmfbt.a" >> js/src/backend.mk

make %{?_smp_mflags}

%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

mv %{buildroot}%{_libdir}/pkgconfig/js.pc %{buildroot}%{_libdir}/pkgconfig/mozjs-%{major}.pc
chmod a-x  %{buildroot}%{_libdir}/pkgconfig/*.pc

# Do not install binaries or static libraries
rm -f %{buildroot}%{_libdir}/*.a %{buildroot}%{_libdir}/*.ajs %{buildroot}%{_bindir}/js*

# Install files, not symlinks to build directory
pushd %{buildroot}%{_includedir}
    for link in `find . -type l`; do
	header=`readlink $link`
	rm -f $link
	cp -p $header $link
    done
popd
cp -p js/src/js-config.h %{buildroot}%{_includedir}/mozjs-%{major}

# Install license file
cp %{SOURCE1} .

%check
# Skip some tests because bundled icu differs from system
rm tests/test262/intl402/ch10/10.2/10.2.3_b.js tests/Intl/DateTimeFormat/format.js tests/ecma_6/String/normalize-generateddata-part1-not-listed.js

tests/jstests.py -d -s --no-progress ../../js/src/js/src/shell/js

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc LICENSE.txt
%doc README.html
%{_libdir}/*.so

%files devel
%{_libdir}/pkgconfig/*.pc
%{_includedir}/mozjs-%{major}

%changelog
* Fri Mar 17 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (38.8.0-1m)
- initial commit Momonga Linux
-- need gjs

* Tue Feb 28 2017 Marek Skalický <mskalick@redhat.com> - 38.8.0-4
- Enable Internationalization api

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 38.8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Sep 19 2016 Marek Skalický <mskalick@redhat.com> - 38.8.0-2
- Fix aarch64 systems with 48-bit VA
  (patch created by Zheng Xu)

* Mon Sep 12 2016 Marek Skalický <mskalick@redhat.com> - 38.8.0-1
- Use firefox sources
- Upgrade to 38.8.0esr

* Thu Mar 31 2016 Marek Skalicky <mskalick@redhat.com> - 38.2.1-8
- Disable two optimizations which caused regressions with new gcc
- Use fedora default -O2 instead of mozjs -O3

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 38.2.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Dec 4 2015 Marek Skalicky <mskalick@redhat.com> - 38.2.1-6
- Make one function from vm/Runtime.cpp visible (needed by MongoDB 3.2)

* Thu Nov 26 2015 Dan Horák <dan[at]danny.cz> - 38.2.1-5
- fix build on s390 (rhbz#1219542)

* Wed Nov 25 2015 Marek Skalicky <mskalick@redhat.com> - 38.2.1-4
- Make two functions from CharacterEncoding.cpp visible (needed by MongoDB)

* Mon Oct 26 2015 Marcin Juszkiewicz <mjuszkiewicz@redhat.com> - 38.2.1-3
- Handle all Fedora 64-bit architectures.

* Tue Oct 13 2015 Marek Skalicky <mskalick@redhat.com> - 38.2.1-2
- Fixed inaccuracies from package review (paraller build, tests don't fail,...)

* Tue Oct 6 2015 Marek Skalicky <mskalick@redhat.com> - 38.2.1-1
- Initial mozjs38 spec (based on mozjs31)
